View Source Appwrite.Types.Locale (appwrite v0.2.1)

Represents locale information for a user based on their IP address.

Fields

  • ip (String.t()): User IP address.
  • country_code (String.t()): Two-character ISO 3166-1 alpha country code.
  • country (String.t()): Country name.
  • continent_code (String.t()): Two-character continent code.
  • continent (String.t()): Continent name.
  • eu (boolean()): Whether the country is part of the European Union.
  • currency (String.t()): ISO 4217 currency code for the country.

Summary

Types

t()

@type t() :: %Appwrite.Types.Locale{
  continent: String.t(),
  continent_code: String.t(),
  country: String.t(),
  country_code: String.t(),
  currency: String.t(),
  eu: boolean(),
  ip: String.t()
}