View Source Appwrite.Types.Team (appwrite v0.2.1)

Represents a team in Appwrite.

Teams allow grouping of users and are used to manage shared access to resources via roles and memberships.

Fields

  • id (String.t()): Team ID.
  • created_at (String.t()): Team creation date in ISO 8601 format.
  • updated_at (String.t()): Team update date in ISO 8601 format.
  • name (String.t()): Team name.
  • total (non_neg_integer()): Total number of team members.
  • prefs (Appwrite.Types.Preference.t()): Team preferences as a string-keyed map.

Summary

Types

t()

@type t() :: %Appwrite.Types.Team{
  created_at: String.t(),
  id: String.t(),
  name: String.t(),
  prefs: Appwrite.Types.Preference.t(),
  total: non_neg_integer(),
  updated_at: String.t()
}